@@ -4,7 +4,6 @@ import re
 
 from django.conf import settings
 from m3.db import BaseEnumerate
-import six
 
 __author__ = 'Andrey Torsunov'
 __contact__ = 'torsunov@bars-open.com'
@@ -41,7 +40,7 @@ class ConfigurableEnum(type):
         settings_name = u'DATALOGGER_{0}'.format(settings_name)
         constants = getattr(settings, settings_name, {})
         assert isinstance(constants, dict)
-        for const_name, value in constants.items():
+        for const_name, value in constants.iteritems():
             assert const_name.isupper()
             assert isinstance(value, tuple) and len(value) == 2
             dct[const_name] = value[0]
@@ -49,7 +48,6 @@ class ConfigurableEnum(type):
         return type.__new__(cls, name, bases, dct)
 
 
-@six.add_metaclass(ConfigurableEnum)
 class EventType(BaseEnumerate):
     u""" Перечисление типов событий.
 
@@ -58,9 +56,9 @@ class EventType(BaseEnumerate):
     - (lse, Юридически важное событие)
 
     """
+    __metaclass__ = ConfigurableEnum
 
 
-@six.add_metaclass(ConfigurableEnum)
 class EventCode(BaseEnumerate):
     u""" Перечисление кодов событий.
 
@@ -69,6 +67,7 @@ class EventCode(BaseEnumerate):
     - (delete, Удаление)
 
     """
+    __metaclass__ = ConfigurableEnum
 
     LOGIN = 'login'
     INSERT = 'insert'
@@ -87,7 +86,6 @@ class EventCode(BaseEnumerate):
     }
 
 
-@six.add_metaclass(ConfigurableEnum)
 class SystemsEnum(BaseEnumerate):
     u""" Перечисление сред логирования.
 
@@ -96,3 +94,4 @@ class SystemsEnum(BaseEnumerate):
     - ('ws', u'Web-сервис')
 
     """
+    __metaclass__ = ConfigurableEnum
