@@ -2,9 +2,9 @@
 import uuid
 from django.db import models
 from django.db.models.signals import class_prepared
-from m3_django_compat import get_model
 
 from .helpers import get_snapshot
+from .enums import EventCode
 
 __author__ = 'Andrey Torsunov'
 __contact__ = 'torsunov@bars-open.com'
@@ -58,9 +58,7 @@ class DataLoggingManager(object):
 
     def post_save(self, instance, created, **kw):
         u""" Сохранение состояния модели в лог при сохранении. """
-        from .enums import EventCode
-
-        DataLog = get_model('datalogging', 'DataLog')
+        DataLog = models.get_model('datalogging', 'DataLog')
         changed = get_snapshot(instance)
         if changed != instance._snapshot:
             event_code = created and EventCode.INSERT or EventCode.UPDATE
@@ -69,7 +67,5 @@ class DataLoggingManager(object):
 
     def post_delete(self, instance, **kw):
         u""" Сохранение состояния модели в лог перед удалением. """
-        from .enums import EventCode
-
-        DataLog = get_model('datalogging', 'DataLog')
+        DataLog = models.get_model('datalogging', 'DataLog')
         DataLog.make_snapshot(instance, EventCode.DELETE)
