@@ -1,7 +1,6 @@
 # coding: utf-8
 import uuid
 import weakref
-from django.utils.deprecation import MiddlewareMixin
 
 from m3_legacy.middleware import get_thread_data
 
@@ -10,7 +9,7 @@ __contact__ = 'torsunov@bars-open.com'
 __docformat__ = 'restructuredtext'
 
 
-class RequestTokenMiddleware(MiddlewareMixin):
+class RequestTokenMiddleware(object):
     u""" Middleware создающее токен для текущего запроса.
 
     Токен в последующем устаналвивается во все возникающие события
@@ -20,10 +19,10 @@ class RequestTokenMiddleware(MiddlewareMixin):
     """
     def process_request(self, request):
         _thread_local = get_thread_data()
-        _thread_local.request_token = str(uuid.uuid4())
+        _thread_local.request_token = unicode(uuid.uuid4())
 
 
-class CaptureRequestMiddleware(MiddlewareMixin):
+class CaptureRequestMiddleware(object):
     u""" Middleware сохраняющее текущий request.
 
     В последующем request используется для получения ряда параметров
