@@ -1,13 +1,11 @@
 # coding: utf-8
-
-import architect
-import datetime
 import uuid
-from itertools import chain
+import datetime
 
+from architect.orms.django.mixins import PartitionableMixin
 from django.db import models
-from m3_django_compat import ModelOptions
-from django.utils.encoding import force_str
+from django.db import connections
+from django.db.utils import ConnectionDoesNotExist
 from json_field import JSONField
 from json_field.fields import JSONEncoder
 
@@ -17,8 +15,6 @@ from .enums import EventCode
 from .signals import (
     msg_for_log_signal, log_context_signal, post_snapshot_signal,
     post_system_event_signal)
-import six
-
 
 __author__ = 'Andrey Torsunov'
 __contact__ = 'torsunov@bars-open.com'
@@ -28,25 +24,32 @@ __docformat__ = 'restructuredtext'
 class LogJSONEncoder(JSONEncoder):
     u""" Наследник JSONEncoder, который умеет работать с ugettext. """
 
-    def default(self, obj):
+    def default(self, o):
         try:
-            ret = super(LogJSONEncoder, self).default(obj)
-        except (UnicodeEncodeError, TypeError, ValueError):
-            ret = force_str(obj)
-
+            ret = super(LogJSONEncoder, self).default(o)
+        except TypeError:
+            ret = unicode(o)
         return ret
 
 
-architect_options = dict(
-    db='datalogger',
-    type='range',
-    subtype='date',
-    constraint='month',
-    column='timestamp')
+class RoutingPartitionableMixin(PartitionableMixin):
+
+    def get_cursor(self):
+        """
+        Нужно учитывать роутинг.
+        """
+        try:
+            cursor = connections[self.PartitionableMeta.db_name].cursor()
+        except AttributeError:
+            cursor = super(RoutingPartitionableMixin, self).get_cursor()
+        except ConnectionDoesNotExist as err:
+            # надо проверить self.PartitionableMeta.db_name
+            raise err
+
+        return cursor
 
 
-@architect.install('partition', **architect_options)
-class DataLog(models.Model):
+class DataLog(RoutingPartitionableMixin, models.Model):
     u""" Лог активности пользователей.
 
     Лог предусматривает отслеживание активности пользователей в системе,
@@ -142,9 +145,13 @@ class DataLog(models.Model):
     context_data.encoder_kwargs.update(ensure_ascii=False)
     object_snapshot.encoder_kwargs.update(ensure_ascii=False)
 
-    class Meta:
-        verbose_name = u'Журнал событий'
-        db_table = u'data_logging'
+    class PartitionableMeta:
+            partition_type = 'range'
+            partition_subtype = 'date'
+            partition_range = 'month'
+            partition_column = 'timestamp'
+            # для роутинга
+            db_name = 'datalogger'
 
     def __init__(self, *args, **kwargs):
         u""" Инициализация записи лога.
@@ -209,16 +216,16 @@ class DataLog(models.Model):
     @staticmethod
     def _diff_normal_field(instance, alias, old_value):
         current_value = getattr(instance, alias, None)
-        field = ModelOptions(instance).get_field_by_name(alias)[0]
+        field = instance._meta.get_field_by_name(alias)[0]
         diff = (old_value or u'(не указано)', current_value)
         return diff, field.verbose_name or alias
 
     @staticmethod
     def _diff_related_field(instance, alias, old_object_id):
-        field = ModelOptions(instance).get_field_by_name(alias)[0]
-        model = field.rel.to if hasattr(field, 'rel') else field.remote_field.model        
+        field = instance._meta.get_field_by_name(alias)[0]
+        model = field.rel.to
         obj = getattr(instance, alias, None)
-        new_val, old_val = six.text_type(obj), u'(не указано)'
+        new_val, old_val = unicode(obj), u'(не указано)'
 
         if old_object_id:
             try:
@@ -226,7 +233,7 @@ class DataLog(models.Model):
             except model.DoesNotExist:
                 old_val = u'(не найден)'
             else:
-                old_val = six.text_type(old_val)
+                old_val = unicode(old_val)
 
         return (old_val, new_val), field.verbose_name or alias
 
@@ -279,14 +286,10 @@ class DataLog(models.Model):
             result_diff = {}
             verbose_names = {}
             cur_snapshot = get_snapshot(instance)
-            name_map = list(set(chain.from_iterable(
-                (field.name, field.attname) if hasattr(field, 'attname') else (
-                field.name,)
-                for field in instance._meta.get_fields()
-                # For complete backwards compatibility, you may want to exclude
-                # GenericForeignKey from the results.
-                if not (field.many_to_one and field.related_model is None)
-            )))
+            try:
+                name_map = instance._meta._name_map
+            except AttributeError:
+                name_map = instance._meta.init_name_map()
 
             # Различие в состояниях экземпляра модели
             state_diff = getattr(instance, '_snapshot', set())
@@ -302,20 +305,10 @@ class DataLog(models.Model):
             log_rec.context_data['diff'] = result_diff
             log_rec.context_data['field_names'] = verbose_names
 
-        snapshot = {}
-
-        for key, val in instance.__dict__.items():
+        snapshot = instance.__dict__.copy()
+        for key in snapshot.keys():
             if key.startswith('_'):
-                continue
-
-            if val is None:
-                snapshot[key] = val
-            else:
-                str_val = force_str(val)
-                if str_val.isdigit():
-                    snapshot[key] = val
-                else:
-                    snapshot[key] = str_val
+                del snapshot[key]
 
         log_rec.object_snapshot = snapshot
         log_rec.verbose = cls.get_verbose_msg(log_rec, instance)
@@ -350,5 +343,6 @@ class DataLog(models.Model):
         if False not in signal_results:
             log_rec.save()
 
-    def __hash__(self):
-        return hash(self.guid)
\ No newline at end of file
+    class Meta:
+        verbose_name = u'Журнал событий'
+        db_table = u'data_logging'
