@@ -8,21 +8,24 @@ from django.dispatch import Signal
 
 from .managers import DataLoggingManager, MANAGER_NAME
 
+__author__ = 'Andrey Torsunov'
+__contact__ = 'torsunov@bars-open.com'
+__docformat__ = 'restructuredtext'
+
 
 suspects = set(getattr(settings, 'DATALOGGER_SUSPECTS_MODEL', []))
 
 if not suspects:
-    msg = 'Список моделей DATALOGGER_SUSPECTS_MODEL пуст'
-    warnings.warn(msg.encode('utf-8'))
-    
+    msg = "Список моделей DATALOGGER_SUSPECTS_MODEL пуст"
+    warnings.warn(msg)
 elif len(suspects) != len(settings.DATALOGGER_SUSPECTS_MODEL):
     # Проверка на дубликаты, в случае их наличия выкидывается warning
-    duplicates = list(copy(settings.DATALOGGER_SUSPECTS_MODEL))
+    dublicates = copy(settings.DATALOGGER_SUSPECTS_MODEL)
     for model_name in suspects:
-        duplicates.remove(model_name)
+        dublicates.remove(model_name)
     msg = (u'Дублированное вхождение в DATALOGGER_SUSPECTS_MODEL '
-           u'модели(ей):{0}').format(duplicates)
-    warnings.warn(msg.encode('utf-8'))
+           u'модели(ей):{0}').format(dublicates)
+    warnings.warn(msg)
 
 
 # Сигналы определяющие поведение методов логгера
